%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%              Signalverarbeitende Systeme               %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Projekt:     Ampelphasenerkennung                      %
%                                                        %
% Autor:       Andre Merkel                              %
%                                                        %
% Studiengang: Business and Systems Engineering          %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% 
%                                                        %
% Beschreibung: Dient der Filterung von                  %
%               grnen Pixeln.                           %
%                                                        %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                        %
% Implementierung: MatLab 2014a                          %     
%                                                        %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                        %
% letzte nderung: 28.05.2015                            %
%                                                        %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function [BinaerBild] = Modul_gruen_erkennen(RGB_Img)
%% Farbe hervorheben

% Zunchst muss die grne Farbe hervorgehoben werden, indem
% die restlichen Farben grau gesetzt werden

% Bild in den HSV-Farbraum konvertieren
HSV_Img = rgb2hsv(RGB_Img);  

% Farbwert bzw Farbwinkel erfassen 
Farbwert = 360.*HSV_Img(:,:,1);

% Sttigung der Farbe erfassen
Saettigung = HSV_Img(:,:,2);  

% Erfassen der rot und gelb Anteile im Bild
Restfarbe = (Farbwert > 190) ;

% Die erfasste Restfarbe in der Sttigung auf "0" setzen
Saettigung(Restfarbe) = 0;  

% Die neuen Werte speichern
HSV_Img(:,:,2) = Saettigung;

% Das obere Verfahren sorgte dafr, das alle nicht grn-Anteile
% nun grau Vorliegen. Als nchstes werden die grnen-Pixel erfasst
% und einheitlich grn gefrbt, sodass alle grnen Pixel genau den 
% gleichen Wert aufweisen. Dadurch ist es spter einfacher zu prfen,
% welche Pixel grn sind und welche nicht. Die restlichen Pixel werden
% schwarz gefrbt (Ausblendung der nicht bentigten Farbe). 

%% Erfassung der Pixelfarbe

for i=1:length(HSV_Img(:,1,1))
    
    for j=1:length(HSV_Img(1,:,1))
        
        R = HSV_Img(i, j, 1);
        G = HSV_Img(i, j, 2);
        B = HSV_Img(i, j, 3);
        
        hP = 360*R;
        
        if  (G < 0.75 || B < 0.75) || (hP < 120) 
            
            % nicht-grne Pixel schwarz frben
            HSV_Img(i, j, 1) = 0;
            HSV_Img(i, j, 2) = 0;
            HSV_Img(i, j, 3) = 0;
            
        else
            
            % grne Pixel einheitlich frben
             HSV_Img(i, j, 1) = 0.4;
             HSV_Img(i, j, 2) = 1;
             HSV_Img(i, j, 3) = 1;
        end
    end
end

%% Pixel abspeichern, zhlen und in den RGB-Raum konvertieren

% Das Bild zurck in den RGB-Farbraum konvertieren
gruen_Bild = hsv2rgb(HSV_Img);    

% binres Bild erzeugen
BinaerBild = im2bw(gruen_Bild);

end

