%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%              Signalverarbeitende Systeme               %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Projekt:     Ampelphasenerkennung                      %
%                                                        %
% Autor:       Andre Merkel                              %
%                                                        %
% Studiengang: Business and Systems Engineering          %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% 
%                                                        %
% Beschreibung: Dient der Filterung von roten Pixeln.    %
%                                                        %
%                                                        %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                        %
% Implementierung: MatLab 2014a                          %     
%                                                        %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                        %
% letzte nderung: 28.05.2015                            %
%                                                        %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function [BinaerBild] = Modul_rot_erkennen(RGB_Img)
%% Farbe hervorheben

% Zunchst muss die rote Farbe hervorgehoben werden, indem
% die restlichen Farben grau gesetzt werden

% Bild in den HSV-Farbraum konvertieren
HSV_Img = rgb2hsv(RGB_Img);

% Farbwert bzw Farbwinkel erfassen
Farbwert = 360.*HSV_Img(:,:,1);    

% Sttigung der Farbe erfassen
Saettigung = HSV_Img(:,:,2);          

% Erfassen der grn und gelb Anteile im Bild
Restfarbe = (Farbwert > 10) & (Farbwert < 340);

% Die erfasste Restfarbe in der Sttigung auf "0" setzen
Saettigung(Restfarbe) = 0; 

% Die neuen Werte speichern
HSV_Img(:,:,2) = Saettigung;          

%% Erfassung der Pixelfarbe

% Das obere Verfahren sorgte dafr, das alle nicht rot-Anteile
% nun grau Vorliegen. Als nchstes werden die roten Pixel erfasst
% und einheitlich rot gefrbt, sodass alle roten Pixel genau den 
% gleichen Wert aufweisen. Dadurch ist es spter einfacher zu prfen,
% welche Pixel rot sind und welche nicht. Die restlichen Pixel werden
% schwarz gefrbt (Ausblendung der nicht bentigten Farbe).

for i=1:length(HSV_Img(:,1,1))
    
    for j=1:length(HSV_Img(1,:,1))
        
        R = HSV_Img(i, j, 1);
        G = HSV_Img(i, j, 2);
        B = HSV_Img(i, j, 3);
        
        if (G < 0.75 || B < 0.75) 
            
            % nicht-rote Pixel schwarz frben
            HSV_Img(i, j, 1) = 0;
            HSV_Img(i, j, 2) = 0;
            HSV_Img(i, j, 3) = 0;
            
        else
            
            % rote Pixel einheitlich frben
            HSV_Img(i, j, 1) = 1;
            HSV_Img(i, j, 2) = 1;
            HSV_Img(i, j, 3) = 1;
        end
        
    end
    
end

%% Pixel abspeichern, zhlen und in den RGB-Raum konvertieren 

% Das Bild zurck in den RGB-Farbraum konvertieren
rot_Bild = hsv2rgb(HSV_Img);  

% binres Bild erzeugen
BinaerBild = im2bw(rot_Bild);

% rote Pixel eintragen
for i=1:length(BinaerBild(:,1))
    
    for j=1:length(BinaerBild(1,:))
        
        if rot_Bild(i,j,1) == 1
            
            BinaerBild(i,j) = 1;
            
        end
    end
end    

end

